<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="rules"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件号" prop="partNo">
            <el-input v-model="dataForm.partNo" placeholder="零件号" disabled>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openSelectPart"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="盘具尺寸(mm)" prop="measurement">
            <el-input
              v-model="dataForm.measurement"
              placeholder="盘具尺寸"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="材质" prop="texture">
            <el-select
              v-model="dataForm.texture"
              filterable
              placeholder="请选择"
              style="width: 100%;"
            >
              <el-option
                v-for="(item, index) in textureOptions"
                :key="index"
                :label="item.label"
                :value="item.value"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="长度(km)" prop="discLength">
            <el-input
              v-model="dataForm.discLength"
              placeholder="长度"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <partDialog :currshowlist.sync="showPart" @listenToPartEvent="selectPart" />
  </el-dialog>
</template>

<script>
import { getObj, putObj, addObj } from '@/api/basic/discmaintenance'
import partDialog from '@/views/common/part.vue'
import { remote } from '@/api/admin/dict'

export default {
  props: {},
  components: {
    partDialog
  },
  data() {
    return {
      visible: false,
      dataForm: {
        id: 0,
        discLength: '',
        partId: '',
        partName: '',
        partNo: '',
        texture: '',
        discNumber: null,
        measurement: ''
      },
      postOptions: [],
      dataRule: {},
      isSubmit: false,
      textureOptions: [],
      showPart: false
    }
  },
  computed: {
    rules: function() {
      return {
        partNo: [
          { required: true, message: '零件号不能为空', trigger: 'blur' }
        ],
        discLength: [
          { required: true, message: '长度不能为空', trigger: 'blur' }
        ]
      }
    }
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    openSelectPart() {
      this.showPart = true
    },
    selectPart(param) {
      if (typeof param !== 'undefined') {
        this.dataForm.partId = param.id
        this.dataForm.partNo = param.partNo
        this.dataForm.partName = param.partName
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          // 校验各种
          // TODO
          if (this.dataForm.id) {
            putObj(this.dataForm)
              .then((data) => {
                this.$message.success('修改成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          } else {
            addObj(this.dataForm)
              .then((data) => {
                this.$message.success('新增成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          }
        } else {
          this.isSubmit = false
        }
      })
    },
    initTextureSelect() {
      remote('texture_type').then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.textureOptions = _data
        }
      })
    }
  },
  created() {
    this.initTextureSelect()
  },
  watch: {}
}
</script>
